dimension property
int?
get
dimension
The embedding dimension of the stored documents, or null while the store is empty.
Implementation
int? get dimension => _inner.dimension;
The embedding dimension of the stored documents, or null while the store is empty.
int? get dimension => _inner.dimension;