upsert method
Inserts documents, replacing any existing document with the same id.
All embeddings must have the same length as the documents already in the store; otherwise an ArgumentError is thrown and the store is left unchanged.
Implementation
@override
Future<void> upsert(List<Document> documents) async {
await _inner.upsert(documents);
if (documents.isEmpty) return;
await _persist();
}